@@ -1,4 +1,4 @@
-import requests
+import httpx
 from ..config import get_base_url
 from ..utils.decorators import deprecated
 from typing import Optional, Dict, Any, List
@@ -6,20 +6,25 @@ from ..exceptions import APIError, BadRequestError
 
 @deprecated("is_valid_data_raw")
 async def is_valid_data(token, data):
-    if not any([key in list(data.keys()) for key in ["url", "email", "phone", "domain", "creditCard", "ip", "wallet", "userAgent", "iban"]]): raise BadRequestError("You must provide at least one parameter.")
-    try:
-        response = requests.post(f"{get_base_url()}/v1/private/secure/verify", json=data, headers={"User-Agent": "DymoAPISDK/1.0.0", "X-Dymo-SDK-Env": "Python", "X-Dymo-SDK-Version" : "0.0.59", "Authorization": token})
-        response.raise_for_status()
-        return response.json()
-    except requests.RequestException as e: raise APIError(str(e))
+    return await is_valid_data_raw(token, data)
 
-async def is_valid_data_raw(token, data):
+async def is_valid_data_raw(token: str, data: dict) -> dict:
     if not any([key in list(data.keys()) for key in ["url", "email", "phone", "domain", "creditCard", "ip", "wallet", "userAgent", "iban"]]): raise BadRequestError("You must provide at least one parameter.")
     try:
-        response = requests.post(f"{get_base_url()}/v1/private/secure/verify", json=data, headers={"User-Agent": "DymoAPISDK/1.0.0", "X-Dymo-SDK-Env": "Python", "X-Dymo-SDK-Version" : "0.0.59", "Authorization": token})
-        response.raise_for_status()
-        return response.json()
-    except requests.RequestException as e: raise APIError(str(e))
+        async with httpx.AsyncClient() as client:
+            resp = await client.post(
+                f"{get_base_url()}/v1/private/secure/verify",
+                json=data,
+                headers={
+                    "User-Agent": "DymoAPISDK/1.0.0",
+                    "X-Dymo-SDK-Env": "Python",
+                    "X-Dymo-SDK-Version": "0.0.60",
+                    "Authorization": token
+                }
+            )
+        resp.raise_for_status()
+        return resp.json()
+    except httpx.RequestError as e: raise APIError(str(e))
 
 async def is_valid_email(token: Optional[str], email: str, rules: Optional[Dict[str, List[str]]] = None) -> Dict[str, Any]:
     """
@@ -51,11 +56,17 @@ async def is_valid_email(token: Optional[str], email: str, rules: Optional[Dict[
     plugins = [p for p in plugins if p is not None]
 
     try:
-        resp = requests.post(
-            f"{get_base_url()}/v1/private/secure/verify",
-            json={"email": email, "plugins": plugins},
-            headers={"User-Agent": "DymoAPISDK/1.0.0", "X-Dymo-SDK-Env": "Python", "X-Dymo-SDK-Version" : "0.0.59", "Authorization": token}
-        )
+        async with httpx.AsyncClient() as client:
+            resp = await client.post(
+                f"{get_base_url()}/v1/private/secure/verify",
+                json={"email": email, "plugins": plugins},
+                headers={
+                    "User-Agent": "DymoAPISDK/1.0.0",
+                    "X-Dymo-SDK-Env": "Python",
+                    "X-Dymo-SDK-Version": "0.0.60",
+                    "Authorization": token
+                }
+            )
         resp.raise_for_status()
         data = resp.json().get("email", {})
 
@@ -88,7 +99,7 @@ async def is_valid_email(token: Optional[str], email: str, rules: Optional[Dict[
             "response": data
         }
 
-    except requests.RequestException as e: raise APIError(f"[Dymo API] {str(e)}")
+    except httpx.RequestError as e: raise APIError(f"[Dymo API] {str(e)}")
 
 async def is_valid_ip(token: Optional[str], ip: str, rules: Optional[Dict[str, List[str]]] = None) -> Dict[str, Any]:
     """
@@ -118,11 +129,17 @@ async def is_valid_ip(token: Optional[str], ip: str, rules: Optional[Dict[str, L
     plugins = [p for p in plugins if p is not None]
 
     try:
-        resp = requests.post(
-            f"{get_base_url()}/v1/private/secure/verify",
-            json={"email": ip, "plugins": plugins},
-            headers={"User-Agent": "DymoAPISDK/1.0.0", "X-Dymo-SDK-Env": "Python", "X-Dymo-SDK-Version" : "0.0.59", "Authorization": token}
-        )
+        async with httpx.AsyncClient() as client:
+            resp = await client.post(
+                f"{get_base_url()}/v1/private/secure/verify",
+                json={"email": ip, "plugins": plugins},
+                headers={
+                    "User-Agent": "DymoAPISDK/1.0.0",
+                    "X-Dymo-SDK-Env": "Python",
+                    "X-Dymo-SDK-Version": "0.0.60",
+                    "Authorization": token
+                }
+            )
         resp.raise_for_status()
         data = resp.json().get("ip", {})
 
@@ -153,7 +170,7 @@ async def is_valid_ip(token: Optional[str], ip: str, rules: Optional[Dict[str, L
             "response": data
         }
 
-    except requests.RequestException as e: raise APIError(f"[Dymo API] {str(e)}")
+    except httpx.RequestError as e: raise APIError(f"[Dymo API] {str(e)}")
 
 async def is_valid_phone(token: Optional[str], phone: str, rules: Optional[Dict[str, List[str]]] = None) -> Dict[str, Any]:
     """
@@ -182,11 +199,17 @@ async def is_valid_phone(token: Optional[str], phone: str, rules: Optional[Dict[
     plugins = [p for p in plugins if p is not None]
 
     try:
-        resp = requests.post(
-            f"{get_base_url()}/v1/private/secure/verify",
-            json={"phone": phone, "plugins": plugins},
-            headers={"User-Agent": "DymoAPISDK/1.0.0", "X-Dymo-SDK-Env": "Python", "X-Dymo-SDK-Version" : "0.0.59", "Authorization": token}
-        )
+        async with httpx.AsyncClient() as client:
+            resp = await client.post(
+                f"{get_base_url()}/v1/private/secure/verify",
+                json={"phone": phone, "plugins": plugins},
+                headers={
+                    "User-Agent": "DymoAPISDK/1.0.0",
+                    "X-Dymo-SDK-Env": "Python",
+                    "X-Dymo-SDK-Version": "0.0.60",
+                    "Authorization": token
+                }
+            )
         resp.raise_for_status()
         data = resp.json().get("phone", {})
 
@@ -216,7 +239,7 @@ async def is_valid_phone(token: Optional[str], phone: str, rules: Optional[Dict[
             "response": data
         }
 
-    except requests.RequestException as e: raise APIError(f"[Dymo API] {str(e)}")
+    except httpx.RequestError as e: raise APIError(f"[Dymo API] {str(e)}")
 
 async def send_email(token, data):
     if not data.get("from"): raise BadRequestError("You must provide an email address from which the following will be sent.")
@@ -224,10 +247,20 @@ async def send_email(token, data):
     if not data.get("subject"): raise BadRequestError("You must provide a subject for the email to be sent.")
     if not data.get("html"): raise BadRequestError("You must provide HTML.")
     try:
-        response = requests.post(f"{get_base_url()}/v1/private/sender/sendEmail", json=data, headers={"User-Agent": "DymoAPISDK/1.0.0", "X-Dymo-SDK-Env": "Python", "X-Dymo-SDK-Version" : "0.0.59", "Authorization": token})
-        response.raise_for_status()
-        return response.json()
-    except requests.RequestException as e: raise APIError(str(e))
+        async with httpx.AsyncClient() as client:
+            resp = await client.post(
+                f"{get_base_url()}/v1/private/sender/sendEmail",
+                json=data,
+                headers={
+                    "User-Agent": "DymoAPISDK/1.0.0",
+                    "X-Dymo-SDK-Env": "Python",
+                    "X-Dymo-SDK-Version": "0.0.60",
+                    "Authorization": token
+                }
+            )
+        resp.raise_for_status()
+        return resp.json()
+    except httpx.RequestError as e: raise APIError(str(e))
 
 async def get_random(token, data):
     if not data.get("from"): raise BadRequestError("You must provide an email address from which the following will be sent.")
@@ -240,26 +273,38 @@ async def get_random(token, data):
     if data.min < -1000000000 or data.min > 1000000000: raise BadRequestError("'min' must be an integer in the interval [-1000000000}, 1000000000].")
     if data.max < -1000000000 or data.max > 1000000000: raise BadRequestError("'max' must be an integer in the interval [-1000000000}, 1000000000].")
     try:
-        response = requests.post(f"{get_base_url()}/v1/private/srng", json=data, headers={"User-Agent": "DymoAPISDK/1.0.0", "X-Dymo-SDK-Env": "Python", "X-Dymo-SDK-Version" : "0.0.59", "Authorization": token})
-        response.raise_for_status()
-        return response.json()
-    except requests.RequestException as e: raise APIError(str(e))
-
+        async with httpx.AsyncClient() as client:
+            resp = await client.post(
+                f"{get_base_url()}/v1/private/srng",
+                json=data,
+                headers={
+                    "User-Agent": "DymoAPISDK/1.0.0",
+                    "X-Dymo-SDK-Env": "Python",
+                    "X-Dymo-SDK-Version": "0.0.60",
+                    "Authorization": token
+                }
+            )
+        resp.raise_for_status()
+        return resp.json()
+    except httpx.RequestError as e: raise APIError(str(e))
 
 async def extract_with_textly(token: str, data: dict) -> dict:
     if not data.get("data"): raise BadRequestError("No data provided.")
     if not data.get("format"): raise BadRequestError("No format provided.")
 
     try:
-        response = requests.post(
-            f"{get_base_url()}/private/textly/extract",
-            json=data,
-            headers={
-                "Content-Type": "application/json",
-                "User-Agent": "DymoAPISDK/1.0.0",
-                "Authorization": token
-            }
-        )
-        response.raise_for_status()
-        return response.json()
-    except requests.RequestException as e: raise APIError(str(e))
\ No newline at end of file
+        async with httpx.AsyncClient() as client:
+            resp = await client.post(
+                f"{get_base_url()}/private/textly/extract",
+                json=data,
+                headers={
+                    "Content-Type": "application/json",
+                    "User-Agent": "DymoAPISDK/1.0.0",
+                    "X-Dymo-SDK-Env": "Python",
+                    "X-Dymo-SDK-Version": "0.0.60",
+                    "Authorization": token
+                }
+            )
+        resp.raise_for_status()
+        return resp.json()
+    except httpx.RequestError as e: raise APIError(str(e))
\ No newline at end of file
