@@ -1,5 +1,5 @@
-import os, sys, logging, importlib 
 from .utils.basics import DotDict
+import os, sys, logging, asyncio, importlib 
 from .config import set_base_url, get_base_url
 import dymoapi.response_models as response_models
 from .services.autoupload import check_for_updates
@@ -49,8 +49,8 @@ class DymoAPI:
     async def _get_function(self, module_name, function_name="main"):
         if module_name == "private" and self.api_key is None and self.root_api_key is None: return logging.error("Invalid private token.")
         func = getattr(importlib.import_module(f".branches.{module_name}", package="dymoapi"), function_name)
-        if module_name == "private": return lambda *args, **kwargs: DotDict(func(self.api_key or self.root_api_key, *args, **kwargs))
-        return lambda *args, **kwargs: DotDict(func(*args, **kwargs))
+        if module_name == "private": return lambda *args, **kwargs: asyncio.to_thread(func, self.api_key or self.root_api_key, *args, **kwargs)
+        return lambda *args, **kwargs: asyncio.to_thread(func, *args, **kwargs)
 
     async def is_valid_data(self, data: response_models.Validator) -> response_models.DataVerifierResponse:
         """
@@ -79,7 +79,8 @@ class DymoAPI:
 
         [Documentation](https://docs.tpeoficial.com/docs/dymo-api/private/data-verifier)
         """
-        response = await self._get_function("private", "is_valid_data")(data)
+        func = await self._get_function("private", "is_valid_data")
+        response = await func(data)
         if response.get("ip",{}).get("as"):
             response["ip"]["_as"] = response["ip"]["as"]
             response["ip"]["_class"] = response["ip"]["class"]
@@ -115,7 +116,8 @@ class DymoAPI:
             https://docs.tpeoficial.com/docs/dymo-api/private/email-validation
         """
         rules_to_use = rules or self.rules.get("email")
-        return await self._get_function("private", "is_valid_email")(email, rules_to_use)
+        func = await self._get_function("private", "is_valid_email")
+        return await func(email, rules_to_use)
     
     async def is_valid_ip(self, ip: str, rules: dict | None = None) -> bool:
         """
@@ -145,7 +147,8 @@ class DymoAPI:
             https://docs.tpeoficial.com/docs/dymo-api/private/ip-validation
         """
         rules_to_use = rules or self.rules.get("ip")
-        return await self._get_function("private", "is_valid_ip")(ip, rules_to_use)
+        func = await self._get_function("private", "is_valid_ip")
+        return await func(ip, rules_to_use)
     
     async def is_valid_phone(self, phone: str, rules: dict | None = None) -> bool:
         """
@@ -175,7 +178,8 @@ class DymoAPI:
             https://docs.tpeoficial.com/docs/dymo-api/private/phone-validation
         """
         rules_to_use = rules or self.rules.get("phone")
-        return await self._get_function("private", "is_valid_phone")(phone, rules_to_use)
+        func = await self._get_function("private", "is_valid_phone")
+        return await func(phone, rules_to_use)
     
     async def send_email(self, data: response_models.EmailStatus) -> response_models.SendEmailResponse:
         """
@@ -210,7 +214,8 @@ class DymoAPI:
         [Documentation](https://docs.tpeoficial.com/docs/dymo-api/private/sender-send-email/getting-started)
         """
         if not self.server_email_config and not self.root_api_key: return logging.error("You must configure the email client settings.")
-        return response_models.DataVerifierResponse(**await self._get_function("private", "send_email")({**data, "serverEmailConfig": self.server_email_config}))
+        func = await self._get_function("private", "send_email")
+        return response_models.DataVerifierResponse(**await func({**data, "serverEmailConfig": self.server_email_config}))
     
     async def get_random(self, data: response_models.SRNG) -> response_models.SRNGResponse:
         """
@@ -234,7 +239,8 @@ class DymoAPI:
             
         [Documentation](https://docs.tpeoficial.com/docs/dymo-api/private/secure-random-number-generator)
         """
-        return response_models.DataVerifierResponse(**await self._get_function("private", "get_random")({**data}))
+        func = await self._get_function("private", "get_random")
+        return response_models.DataVerifierResponse(**await func({**data}))
     
     async def extract_with_textly(self, data: response_models.Textly) -> response_models.TextlyResponse:
         """
@@ -258,7 +264,8 @@ class DymoAPI:
 
         [Documentation](https://docs.tpeoficial.com/docs/dymo-api/private/extract-textly)
         """        
-        return response_models.ExtractWithTextlyResponse(**await self._get_function("private", "extract_with_textly")({**data}))
+        func = await self._get_function("private", "extract_with_textly")
+        return response_models.ExtractWithTextlyResponse(**await func({**data}))
 
     async def get_prayer_times(self, data: response_models.PrayerTimesData) -> response_models.PrayerTimesResponse:
         """
@@ -284,7 +291,8 @@ class DymoAPI:
 
         [Documentation](https://docs.tpeoficial.com/docs/dymo-api/public/prayertimes)
         """
-        return response_models.PrayerTimesResponse(**await self._get_function("public", "get_prayer_times")(data))
+        func = await self._get_function("public", "get_prayer_times")
+        return response_models.PrayerTimesResponse(**await func(data))
 
     async def satinizer(self, data: response_models.InputSanitizerData) -> response_models.SatinizerResponse:
         """
@@ -304,7 +312,8 @@ class DymoAPI:
 
         [Documentation](https://docs.tpeoficial.com/docs/dymo-api/public/input-satinizer)
         """
-        return response_models.SatinizerResponse(**await self._get_function("public", "satinizer")(data))
+        func = await self._get_function("public", "satinizer")
+        return response_models.SatinizerResponse(**await func(data))
 
     async def is_valid_pwd(self, data: response_models.IsValidPwdData) -> response_models.IsValidPwdResponse:
         """
@@ -339,9 +348,11 @@ class DymoAPI:
 
         [Documentation](https://docs.tpeoficial.com/docs/dymo-api/public/password-validator)
         """
-        return response_models.IsValidPwdResponse(**await self._get_function("public", "is_valid_pwd")(data))
+        func = await self._get_function("public", "is_valid_pwd")
+        return response_models.IsValidPwdResponse(**await func(data))
 
     async def new_url_encrypt(self, data) -> response_models.UrlEncryptResponse:
-        return response_models.UrlEncryptResponse(**await self._get_function("public", "new_url_encrypt")(data))
+        func = await self._get_function("public", "new_url_encrypt")
+        return response_models.UrlEncryptResponse(**await func(data))
     
 if __name__ == "__main__": sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
\ No newline at end of file
